@@ -7,7 +7,7 @@ These applicatiors are used to add features to the input data in the correspondi
 
 """
 from abc import ABC, abstractmethod
-from typing import List, Optional, Union
+from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
@@ -32,9 +32,9 @@ class AbstractFeatureApplicator(ABC):
 
     def __init__(
         self,
-        horizons: Union[List[float], str],
-        feature_names: Optional[List[str]] = None,
-        feature_modules: Optional[List[str]] = [],
+        horizons: Union[list[float], str],
+        feature_names: Optional[list[str]] = None,
+        feature_modules: Optional[list[str]] = [],
     ) -> None:
         """Initialize abstract feature applicator.
 
@@ -77,6 +77,7 @@ class TrainFeatureApplicator(AbstractFeatureApplicator):
         df: pd.DataFrame,
         pj: PredictionJobDataClass = None,
         latency_config: dict = None,
+        use_old_model_features: bool = True,
     ) -> pd.DataFrame:
         """Adds features to an input DataFrame.
 
@@ -95,6 +96,7 @@ class TrainFeatureApplicator(AbstractFeatureApplicator):
             latency_config: (Optional) Invalidate certain features that are not
                 available for a specific horizon due to data latency. Defaults to
                 ``{"APX": 24}``.
+            use_old_model_features: Check if any new features are added since the features of the last model, reject any new features.
 
         Returns:
             Input DataFrame with an extra column for every added feature and sorted on the datetime index.
@@ -154,7 +156,8 @@ class TrainFeatureApplicator(AbstractFeatureApplicator):
                 features = self.feature_names + ["historic_load"] + ["horizon"]
             else:
                 features = self.feature_names + ["horizon"]
-            result = remove_non_requested_feature_columns(result, features)
+            if use_old_model_features:
+                result = remove_non_requested_feature_columns(result, features)
 
         # Sort all features except for the (first) load and (last) horizon columns
         return enforce_feature_order(result)
